package com.example.mystictale.Screen.passwordRecovery

import android.util.Patterns
import android.widget.Toast
import androidx.compose.foundation.Image
import androidx.compose.foundation.gestures.detectTapGestures
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.paint
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.platform.LocalSoftwareKeyboardController
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.mystictale.R
import com.example.mystictale.ViewModels.AuthViewModel
import com.example.mystictale.navigation.Screens
import com.example.mystictale.resources.components.GenericTextField
import com.example.mystictale.resources.components.Loading
import com.example.mystictale.resources.getUserIdByEmail
import com.example.mystictale.ui.theme.DarkPurple
import com.example.mystictale.ui.theme.OpenSans
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch

@Composable
fun PasswordRecovery(navController: NavController, viewModel: AuthViewModel) {
    val focusManager = LocalFocusManager.current
    val context = LocalContext.current
    val keyboardController = LocalSoftwareKeyboardController.current
    val email = remember {
        mutableStateOf("")
    }
    val flag = remember {
        mutableStateOf(false)
    }
    val emailFlag = remember { mutableStateOf(false) }
    Column(
        Modifier
            .fillMaxSize()
            .paint(
                painterResource(id = R.drawable.background),
                contentScale = ContentScale.FillBounds
            )
            .pointerInput(Unit) {
                detectTapGestures(onTap = {
                    keyboardController?.hide()
                    focusManager.clearFocus()
                })
            }
            .padding(10.dp),
        verticalArrangement = Arrangement.SpaceBetween,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {

        Column {
            Row(
                modifier = Modifier
                    .padding(top = 30.dp)
                    .height(40.dp)
                    .fillMaxWidth(),
                horizontalArrangement = Arrangement.Start,
                verticalAlignment = Alignment.Top
            ) {
                Button(
                    onClick = { navController.navigate(Screens.SingIn.route) },
                    colors = ButtonColors(
                        disabledContentColor = Color.White,
                        disabledContainerColor = Color.Transparent,
                        contentColor = Color.White,
                        containerColor = Color.Transparent
                    )
                ) {
                    Image(
                        painter = painterResource(id = R.drawable.back),
                        contentDescription = "back",
                        modifier = Modifier
                            .width(11.dp)
                            .height(14.dp)
                    )
                }
            }
            Column(
                modifier = Modifier
                    .padding(20.dp)
                    .padding(start = 15.dp, end = 5.dp)
            ) {
                Spacer(modifier = Modifier.height(10.dp))
                Text(
                    text = "Сброс пароля",
                    fontWeight = FontWeight.Bold,
                    fontFamily = OpenSans,
                    fontSize = 24.sp,
                    color = Color.White,
                    modifier = Modifier
                        .fillMaxWidth(),
                    style = MaterialTheme.typography.headlineMedium
                )
                Spacer(modifier = Modifier.height(30.dp))

                Text(
                    text = "Укажите свой адрес электронной почты, чтобы мы могли найти Ваш аккаунт",
                    fontWeight = FontWeight.Light,
                    fontFamily = OpenSans,
                    fontSize = 15.sp,
                    color = Color.White,
                    modifier = Modifier
                        .fillMaxWidth()
                )
                Spacer(modifier = Modifier.height(30.dp))


                GenericTextField(
                    email.value,
                    {
                        email.value = it
                        emailFlag.value = false
                    },
                    "E-mail",
                    KeyboardType.Email,
                    emailFlag.value
                )

                if (emailFlag.value) {
                    Text(
                        "Неверно введена почта",
                        fontWeight = FontWeight.Light,
                        fontFamily = OpenSans,
                        fontSize = 13.sp,
                        color = Color.Red
                    )
                }

            }

        }

        Box(Modifier.padding(bottom = 50.dp)) {
            Button(
                onClick = {
                    if (Patterns.EMAIL_ADDRESS.matcher(email.value).matches()) {
                        CoroutineScope(Dispatchers.Main).launch {
                            flag.value = true
                            val userId = getUserIdByEmail(email.value)
                            if (userId != null) {
                                viewModel.uid = userId
                                flag.value = false
                                navController.navigate(Screens.NewPassword.route)
                            } else {
                                flag.value = false
                                Toast.makeText(context, "Аккаунт не найден", Toast.LENGTH_SHORT)
                                    .show()
                            }
                        }
                    } else {
                        emailFlag.value = true
                    }

                },
                modifier = Modifier
                    .fillMaxWidth()
                    .height(48.dp)
                    .padding(horizontal = 30.dp),
                shape = RoundedCornerShape(12.dp),
                colors = ButtonColors(
                    containerColor = DarkPurple,
                    contentColor = Color.White,
                    disabledContentColor = Color.White,
                    disabledContainerColor = DarkPurple
                )
            ) {
                Text("Далее", fontSize = 20.sp, fontWeight = FontWeight.Bold)

            }

        }


    }
    if (flag.value) {
        Loading()
    }
}