package com.example.mystictale.Screen.registration

import android.widget.Toast
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.paint
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.StrokeCap
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.mystictale.R
import com.example.mystictale.ViewModels.AuthViewModel
import com.example.mystictale.models.UserState
import com.example.mystictale.navigation.Screens
import com.example.mystictale.resources.components.ChooseGender
import com.example.mystictale.resources.components.Loading
import com.example.mystictale.ui.theme.DarkPurple
import com.example.mystictale.ui.theme.OpenSans

@Composable
fun RegistrationGender(navController: NavController, viewModel: AuthViewModel) {
    val userState by viewModel.userState
    val flag = remember { mutableStateOf(false) }
    val flag2 = remember { mutableStateOf(false) }
    val genderFlag = remember { mutableStateOf(false) }

    val context = LocalContext.current
    Column(
        Modifier
            .fillMaxSize()
            .paint(
                painterResource(id = R.drawable.background),
                contentScale = ContentScale.FillBounds
            )
            .padding(10.dp),
        verticalArrangement = Arrangement.SpaceBetween,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {

        Column {
            Box(
                modifier = Modifier
                    .padding(top = 30.dp)
                    .height(40.dp)
                    .fillMaxWidth(),
                contentAlignment = Alignment.TopStart
            ) {
                Button(
                    onClick = { navController.navigate(Screens.RegistrationDateOfBirth.route) },
                    colors = ButtonColors(
                        disabledContentColor = Color.White,
                        disabledContainerColor = Color.Transparent,
                        contentColor = Color.White,
                        containerColor = Color.Transparent
                    )
                ) {
                    Image(
                        painter = painterResource(id = R.drawable.back),
                        contentDescription = "back",
                        modifier = Modifier
                            .width(11.dp)
                            .height(14.dp)
                    )
                }
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(top = 22.dp),
                    horizontalArrangement = Arrangement.Center,
                    verticalAlignment = Alignment.CenterVertically
                ) {


                    LinearProgressIndicator(
                        progress = { 1f },
                        modifier = Modifier.width(157.dp),
                        color = Color(0xFF28176B),
                        trackColor = Color(0xFFA1A0A3),
                        strokeCap = StrokeCap.Round,
                    )
                }
            }
            Column(
                modifier = Modifier
                    .padding(20.dp)
                    .padding(start = 15.dp, end = 5.dp)
            ) {
                Spacer(modifier = Modifier.height(30.dp))
                Text(
                    text = "Ваш пол",
                    fontWeight = FontWeight.Bold,
                    fontFamily = OpenSans,
                    fontSize = 24.sp,
                    color = Color.White,
                    modifier = Modifier
                        .fillMaxWidth(),
                    style = MaterialTheme.typography.headlineMedium
                )
                Spacer(modifier = Modifier.height(30.dp))
                ChooseGender(viewModel)
                if(genderFlag.value){
                    Text(
                        "Выберете пол",
                        fontWeight = FontWeight.Light,
                        fontFamily = OpenSans,
                        fontSize = 13.sp,
                        color = Color.Red
                    )
                }

            }
        }
        Box(Modifier.padding(bottom = 40.dp)) {
            Button(
                onClick = {
                    if(viewModel.gender==null){
                        genderFlag.value = true
                    }
                    else{
                        viewModel.onSignUpEmailPassword(context = context)
                        flag.value = true
                    }
                },
                modifier = Modifier
                    .fillMaxWidth()
                    .height(48.dp)
                    .padding(horizontal = 30.dp),
                shape = RoundedCornerShape(12.dp),
                colors = ButtonColors(
                    containerColor = DarkPurple,
                    contentColor = Color.White,
                    disabledContentColor = Color.White,
                    disabledContainerColor = DarkPurple
                )
            ) {
                Text("Завершить", fontSize = 20.sp, fontWeight = FontWeight.Bold)

            }

        }


    }
    if (flag.value) {
        when (userState) {
            is UserState.Loading -> {
                Loading()
            }

            is UserState.Success -> {
                viewModel.addProfile()
                flag2.value = true
                flag.value = false
            }

            is UserState.Error -> {
                val message = (userState as UserState.Error).message
                Toast.makeText(context, message, Toast.LENGTH_SHORT).show()
                flag.value = false
            }
        }
    }
    if (flag2.value) {
        when (userState) {
            is UserState.Loading -> {
                Loading()
            }

            is UserState.Success -> {
                navController.navigate(Screens.Start.route)
                flag2.value = false
            }

            is UserState.Error -> {
                val message = (userState as UserState.Error).message
                Toast.makeText(context, message, Toast.LENGTH_SHORT).show()
                flag2.value = false
            }
        }
    }

}