package com.example.mystictale.Screen.signIn

import android.util.Patterns
import android.widget.Toast
import androidx.activity.compose.BackHandler
import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.gestures.detectTapGestures
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.paint
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.platform.LocalSoftwareKeyboardController
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.mystictale.R
import com.example.mystictale.ViewModels.AuthViewModel
import com.example.mystictale.models.UserState
import com.example.mystictale.navigation.Screens
import com.example.mystictale.resources.components.GenericTextField
import com.example.mystictale.resources.components.Loading
import com.example.mystictale.resources.components.PasswordTextField
import com.example.mystictale.ui.theme.DarkPurple
import com.example.mystictale.ui.theme.Grey
import com.example.mystictale.ui.theme.OpenSans

@Composable
fun SignIn(navController: NavController, viewModel: AuthViewModel) {
    val focusManager = LocalFocusManager.current
    val keyboardController = LocalSoftwareKeyboardController.current
    val context = LocalContext.current
    val email = remember {
        mutableStateOf("")
    }
    val password = remember {
        mutableStateOf("")
    }
    val flagEmail = remember {
        mutableStateOf(false)
    }
    val flagPassword = remember {
        mutableStateOf(false)
    }
    val userState by viewModel.userState
    val flag = remember {
        mutableStateOf(false)
    }
    Column(
        Modifier
            .fillMaxSize()
            .paint(
                painterResource(id = R.drawable.background),
                contentScale = ContentScale.FillBounds
            )
            .pointerInput(Unit) {
                detectTapGestures(onTap = {
                    keyboardController?.hide()
                    focusManager.clearFocus()
                })
            },
        verticalArrangement = Arrangement.SpaceBetween,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {

        Column {
            Box(
                modifier = Modifier
                    .padding(top = 30.dp)
                    .height(40.dp)
                    .fillMaxWidth(),
                contentAlignment = Alignment.TopStart
            ) {
                Button(
                    onClick = { navController.navigate(Screens.Start.route) },
                    colors = ButtonColors(
                        disabledContentColor = Color.White,
                        disabledContainerColor = Color.Transparent,
                        contentColor = Color.White,
                        containerColor = Color.Transparent
                    )
                ) {
                    Image(
                        painter = painterResource(id = R.drawable.back),
                        contentDescription = "back",
                        modifier = Modifier
                            .width(11.dp)
                            .height(14.dp)
                    )
                }
            }
            Column(
                modifier = Modifier
                    .padding(20.dp)
                    .padding(start = 15.dp, end = 5.dp)
            ) {
                Spacer(modifier = Modifier.height(10.dp))
                Text(
                    text = "Авторизация",
                    fontWeight = FontWeight.Bold,
                    fontFamily = OpenSans,
                    fontSize = 24.sp,
                    color = Color.White,
                    modifier = Modifier
                        .fillMaxWidth(),
                    style = MaterialTheme.typography.headlineMedium
                )
                Spacer(modifier = Modifier.height(30.dp))

                GenericTextField(
                    email.value,
                    {
                        email.value = it
                        flagEmail.value = false
                    },
                    "E-mail",
                    KeyboardType.Email,
                    flagEmail.value
                )
                if (flagEmail.value) {
                    if (email.value.isEmpty()) {
                        Text(
                            "Введите почту",
                            fontWeight = FontWeight.Light,
                            fontFamily = OpenSans,
                            fontSize = 13.sp,
                            color = Color.Red
                        )
                    } else if (!Patterns.EMAIL_ADDRESS.matcher(email.value).matches()) {
                        Text(
                            "Неверная почта",
                            fontWeight = FontWeight.Light,
                            fontFamily = OpenSans,
                            fontSize = 13.sp,
                            color = Color.Red
                        )
                    }
                }
                Spacer(modifier = Modifier.height(30.dp))
                PasswordTextField(
                    password.value,
                    {
                        password.value = it
                        flagPassword.value = false
                    },
                    "Пароль",
                    flagPassword.value
                )
                if (flagPassword.value) {
                    Text(
                        "Введите пароль",
                        fontWeight = FontWeight.Light,
                        fontFamily = OpenSans,
                        fontSize = 13.sp,
                        color = Color.Red
                    )
                }
                Spacer(modifier = Modifier.height(30.dp))
                Text(
                    "Забыли пароль?",
                    fontFamily = OpenSans,
                    fontSize = 13.sp,
                    fontWeight = FontWeight.Light,
                    color = Grey,
                    modifier = Modifier
                        .clickable { navController.navigate(Screens.PasswordRecovery.route) }
                )
            }
        }

        Box(Modifier.padding(bottom = 50.dp)) {
            Button(
                onClick = {
                    if (!Patterns.EMAIL_ADDRESS.matcher(email.value)
                            .matches() || email.value.isEmpty()
                    ) {
                        flagEmail.value = true
                    }
                    if (password.value.isEmpty()) {
                        flagPassword.value = true
                    }
                    if (Patterns.EMAIL_ADDRESS.matcher(email.value)
                            .matches() && email.value.isNotEmpty() && password.value.isNotEmpty()
                    ) {
                        viewModel.onSignInEmailPassword(
                            emailUser = email.value,
                            passwordUser = password.value,
                            context = context
                        )
                        flag.value = true

                    }
                },
                modifier = Modifier
                    .fillMaxWidth()
                    .height(48.dp)
                    .padding(horizontal = 30.dp),
                shape = RoundedCornerShape(12.dp),
                colors = ButtonColors(
                    containerColor = DarkPurple,
                    contentColor = Color.White,
                    disabledContentColor = Color.White,
                    disabledContainerColor = DarkPurple
                )
            ) {
                Text("Далее", fontSize = 20.sp, fontWeight = FontWeight.Bold)

            }

        }


    }
    if (flag.value) {
        when (userState) {
            is UserState.Loading -> {
                Loading()
            }

            is UserState.Success -> {
                navController.navigate(Screens.Profile.route)
                flag.value = false
            }

            is UserState.Error -> {
                val message = (userState as UserState.Error).message
                Toast.makeText(context, message, Toast.LENGTH_SHORT).show()
                flag.value = false
            }

        }
    }
}